Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7)

Unified Diff: components/sync/engine_impl/test_entry_factory.h

Issue 2442583003: [Sync] Start implementation of migration for USS. (Closed)
Patch Set: Rebase. Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/sync/engine_impl/test_entry_factory.h
diff --git a/components/sync/engine_impl/test_entry_factory.h b/components/sync/engine_impl/test_entry_factory.h
index a5d160cf69ceca7d10ecf415940300f4382d58b6..34fe4e987381b458a1d77de51fa6bc504ab1e6de 100644
--- a/components/sync/engine_impl/test_entry_factory.h
+++ b/components/sync/engine_impl/test_entry_factory.h
@@ -58,11 +58,18 @@ class TestEntryFactory {
int64_t CreateUnappliedAndUnsyncedBookmarkItem(const std::string& name);
// Creates a unique_client_tag item that has neither IS_UNSYNED or
// IS_UNAPPLIED_UPDATE. The item is known to both the server and client.
// Returns the metahandle of the created item.
int64_t CreateSyncedItem(const std::string& name,
ModelType model_type,
bool is_folder);
+ int64_t CreateSyncedItem(const std::string& name,
+ ModelType model_type,
+ bool is_folder,
+ const sync_pb::EntitySpecifics& specifics);
+
+ // Creates a root node for |model_type|.
+ int64_t CreateTypeRootNode(ModelType model_type);
// Creates a root node that IS_UNAPPLIED. Similar to what one would find in
// the database between the ProcessUpdates of an initial datatype configure
@@ -58,11 +58,18 @@ class TestEntryFactory {
int64_t CreateUnappliedAndUnsyncedBookmarkItem(const std::string& name);
// Creates a unique_client_tag item that has neither IS_UNSYNED or
- // IS_UNAPPLIED_UPDATE. The item is known to both the server and client.
- // Returns the metahandle of the created item.
+ // IS_UNAPPLIED_UPDATE. The item is known to both the server and client.
+ // Returns the metahandle of the created item. |specifics| is optional.
int64_t CreateSyncedItem(const std::string& name,
ModelType model_type,

Powered by Google App Engine
This is Rietveld 408576698